==> xwiki-rendering-wikimodel-4.5.3-sources.jar: org/xwiki/rendering/wikimodel/xhtml/handler/BreakTagHandler.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.wikimodel.xhtml.handler;

import org.xwiki.rendering.wikimodel.WikiParameters;
import org.xwiki.rendering.wikimodel.xhtml.impl.XhtmlHandler.TagStack.TagContext;

/**
 * @version $Id: 86bda78dbbd960241d81387c4c58d230be10b3bf $
 * @since 4.0M1
 */
public class BreakTagHandler extends TagHandler
{
    public BreakTagHandler()
    {
        super(false, false, false);
    }

    @Override
    protected void begin(TagContext context)
    {
        // If we're inside a quotation line then a BR must close the current
        // quotation line and start a new quotation line.
        int quoteDepth = (Integer) context.getTagStack().getStackParameter(
            QuoteTagHandler.QUOTEDEPTH);
        if (quoteDepth > 0) {
            context.getScannerContext().beginQuotLine(quoteDepth);

            // duplicate span on several quotation lines
            WikiParameters spanParameters;
            for (int i = 0; (spanParameters = (WikiParameters) context
                .getTagStack().getStackParameter(
                    AbstractFormatTagHandler.FORMATPARAMETERS, i)) != null; ++i)
            {
                context.getScannerContext().beginFormat(spanParameters);
            }
        } else {
            context.getScannerContext().onNewLine();
        }
    }
}

==> xwiki-rendering-wikimodel-6.3-sources.jar: org/xwiki/rendering/wikimodel/xhtml/handler/BreakTagHandler.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.wikimodel.xhtml.handler;

import java.util.Iterator;

import org.xwiki.rendering.wikimodel.WikiParameters;
import org.xwiki.rendering.wikimodel.xhtml.impl.XhtmlHandler.TagStack.TagContext;

/**
 * @version $Id: 36f4808a39cbfe91281e1898ad1a34ef247d0421 $
 * @since 4.0M1
 */
public class BreakTagHandler extends TagHandler
{
    public BreakTagHandler()
    {
        super(false, false, false);
    }

    @Override
    protected void begin(TagContext context)
    {
        // If we're inside a quotation line then a BR must close the current
        // quotation line and start a new quotation line.
        int quoteDepth = (Integer) context.getTagStack().getStackParameter(
            QuoteTagHandler.QUOTEDEPTH);
        if (quoteDepth > 0) {
            context.getScannerContext().beginQuotLine(quoteDepth);

            // duplicate span on several quotation lines
            Iterator it = context.getTagStack().getStackParameterIterator(AbstractFormatTagHandler.FORMATPARAMETERS);
            if (it != null) {
                while (it.hasNext()) {
                    WikiParameters spanParameters = (WikiParameters) it.next();
                    context.getScannerContext().beginFormat(spanParameters);
                }
            }
        } else {
            context.getScannerContext().onNewLine();
        }
    }
}
